@@ -11,8 +11,10 @@ function _aws_cdk_app_delivery_PipelineDeployStackActionProps(p) {
             print("@aws-cdk/app-delivery.PipelineDeployStackActionProps#stack", "");
         if ("capabilities" in p)
             print("@aws-cdk/app-delivery.PipelineDeployStackActionProps#capabilities", "");
-        if (!visitedObjects.has(p.capabilities))
-            require("@aws-cdk/aws-cloudformation/.warnings.jsii.js")._aws_cdk_aws_cloudformation_CloudFormationCapabilities(p.capabilities);
+        if (p.capabilities != null)
+            for (const o of p.capabilities)
+                if (!visitedObjects.has(o))
+                    require("@aws-cdk/aws-cloudformation/.warnings.jsii.js")._aws_cdk_aws_cloudformation_CloudFormationCapabilities(o);
         if ("changeSetName" in p)
             print("@aws-cdk/app-delivery.PipelineDeployStackActionProps#changeSetName", "");
         if ("createChangeSetActionName" in p)
